
def __init__(self):
    print('constructor')
def adding(self,n1,n2):
    return(n1+n2)


